@@ -1,19 +1,14 @@
 SES.temporal = function(target, reps = NULL, group, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
-                        hash=FALSE, hashObject=NULL, slopes = FALSE, ncores = 1, logged = FALSE)
-{
-  #get the log threshold
-  threshold = log(threshold)
+                        hash=FALSE, hashObject = NULL, slopes = FALSE, ncores = 1) {
   ##############################
   # initialization part of SES #
   ##############################
-  equal_case = 3;
   stat_hash = NULL;
   pvalue_hash = NULL;
-  
+ 
   if ( hash )  {
     if ( requireNamespace("hash") ) {
-      if(is.null(hashObject))
-      {
+      if ( is.null(hashObject) )  {
         stat_hash = hash();
         pvalue_hash = hash();
       } else if(class(hashObject) == "list"){
@@ -26,8 +21,6 @@ SES.temporal = function(target, reps = NULL, group, dataset, max_k = 3, threshol
       return(NULL);
     }
   }
-  
-  dataInfo = NULL;
   ###################################
   # dataset checking and initialize #
   ###################################
@@ -54,7 +47,6 @@ SES.temporal = function(target, reps = NULL, group, dataset, max_k = 3, threshol
     target <- dataset[ , targetID];
   }
   
-  test = "testIndGLMM";
   #checking if target is a single number
   if (is.numeric(target) & length(target) == 1) {
     if (target > dim(dataset)[2]){
@@ -73,31 +65,30 @@ SES.temporal = function(target, reps = NULL, group, dataset, max_k = 3, threshol
     test = user_test;
   } else {
     #auto detect independence test in case of not defined by the user and the test is null or auto
-    if (is.null(test) || test == "auto")  test = "testIndGLMM"
-    #if target is a factor then use the Logistic test
-    
-    if ( la == 2) {
-      dataInfo$target_type = "binary";
-      cat('\nTarget variable type: Binary')
-    } else if (sum( floor(target) - target ) == 0 ) {
-      dataInfo$target_type = "discrete";
-      cat('\nTarget variable type: Discrete')
-    } else {
-      dataInfo$target_type = "normal";
-      cat('\nTarget variable type: Continuous')
-    }
-    cat("\nConditional independence test used: ");cat(test);cat("\n");
+    if ( is.null(test) || test == "auto" )  {
+      if ( la > 2 & sum(target - round(target) ) != 0  &  is.null(wei)  &  !slopes  &  is.null(reps) ) {
+        test <- "testIndLMM"
+      } else if (la == 2) {
+        test = "testIndGLMMLogistic"
+      } else if ( la > 2  &  sum(target - round(target)) == 0 ) {
+        test = "testIndGLMMPois"
+      } else test = "testIndGLMMReg"
+    }  
     #available conditional independence tests
-    av_tests = c("testIndGLMM", "auto",  NULL);
+    av_tests = c("testIndGLMMReg", "testIndGLMMLogistic", "testIndGLMMPois", "testIndLMM", "auto",  NULL);
     
     ci_test = test
     if (length(test) == 1) {   #avoid vectors, matrices etc
-      test = match.arg(test , av_tests ,TRUE);
-      #convert to closure type
-      if (test == "testIndGLMM") {
-        test = testIndGLMM;
+      test = match.arg(test, av_tests, TRUE);
+      if(test == "testIndGLMMReg") {
+        test = testIndGLMMReg;
+      } else if(test == "testIndGLMMLogistic") {
+        test = testIndGLMMLogistic;
+      } else if (test == "testIndGLMMPois") {
+        test = testIndGLMMPois;
+      } else if (test == "testIndLMM") {
+        test <- testIndLMM
       }
-      
     } else   stop('invalid test option');
   }
   ###################################
@@ -109,14 +100,16 @@ SES.temporal = function(target, reps = NULL, group, dataset, max_k = 3, threshol
   #option checking
   if ( (typeof(max_k) != "double") || max_k < 1 )   stop('invalid max_k option');
   if (max_k > varsize)   max_k = varsize;
-  if ( (typeof(threshold) != "double") || exp(threshold) == 0 || exp(threshold) > 1 )   stop('invalid threshold option');
-  if ( typeof(equal_case) != "double" )   stop('invalid equal_case option');
+  if ( (typeof(threshold) != "double") || threshold <= 0 || threshold >= 1 )   stop('invalid threshold option');
   ######################################################################################
   if( !is.null(user_test) )  ci_test = "user_test";
   #######################################################################################
   #call the main SES function after the checks and the initializations
-  results = InternalSES.temporal(target, reps, group, dataset, max_k, threshold, test, ini, wei, equal_case, user_test, dataInfo, hash, varsize, stat_hash, pvalue_hash, targetID, slopes, ncores, logged = logged);
-  SES.temporal.output <-new("SES.temporal.output", selectedVars = results$selectedVars, selectedVarsOrder=results$selectedVarsOrder, queues=results$queues, signatures=results$signatures, hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, univ = results$uni, max_k=results$max_k, threshold = results$threshold, runtime=results$runtime, test=ci_test, slope = results$slope);
+  results = InternalSES.temporal(target, reps, group, dataset, max_k, log(threshold), test, ini, wei, user_test, hash, varsize, stat_hash, pvalue_hash, 
+                                 targetID, slopes, ncores);
+  SES.temporal.output <-new("SES.temporal.output", selectedVars = results$selectedVars, selectedVarsOrder=results$selectedVarsOrder, queues=results$queues, 
+                            signatures=results$signatures, hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, univ = results$uni, 
+                            max_k=results$max_k, threshold = results$threshold, runtime=results$runtime, test = ci_test, slope = results$slope);
   
   return(SES.temporal.output);
 }
