@@ -43,11 +43,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
     while ( sum(s>0) > 0 ) {
       for ( i in ind[s] )  {
         fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-        lik2[i] <- 2 * fit2$loglik
+        lik2[i] <- fit2$loglik
         dof[i] <- length( fit2$be )
       }
       n.tests <- n.tests + length( ind[s] ) 
-      stat <- lik2 - lik1
+      stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig) 
       sel <- which.min(pval) * ( length(s)>0 )
@@ -68,11 +68,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
   if (K == 1) {
     for ( i in ind[-sela] )  {
       fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-      lik2[i] <- 2 * fit2$loglik
+      lik2[i] <- fit2$loglik
       dof[i] <- length( fit2$be )
     }
     n.tests[2] <- length( ind[-sela] )
-    stat <- lik2 - lik1
+    stat <- 2 * (lik2 - lik1)
     pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
     s <- which(pval < sig)
     sel <- which.min(pval) * ( length(s)>0 )
@@ -89,11 +89,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
     while ( sum(s>0) > 0 ) {
       for ( i in ind[s] )  {
         fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-        lik2[i] <- 2 * fit2$loglik
+        lik2[i] <- fit2$loglik
         dof[i] <- length( fit2$be )
       }
       n.tests[2] <- n.tests[2] + length( ind[s] )
-      stat <- lik2 - lik1
+      stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
       sel <- which.min(pval) * ( length(s)>0 )
@@ -115,11 +115,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
     
     for ( i in ind[-sela] )  {
       fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-      lik2[i] <- 2 * fit2$loglik
+      lik2[i] <- fit2$loglik
       dof[i] <- length( fit2$be )
     }
     n.tests[2] <- length( ind[-sela] ) 
-    stat <- lik2 - lik1
+    stat <- 2 * (lik2 - lik1)
     pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
     s <- which(pval < sig)
     sel <- which.min(pval) * ( length(s)>0 )
@@ -136,11 +136,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
     while ( sum(s > 0) > 0 ) {
       for ( i in ind[s] )  {
         fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-        lik2[i] <- 2 * fit2$loglik
+        lik2[i] <- fit2$loglik
         dof[i] <- length( fit2$be )
       }
       n.tests[2] <- n.tests[2] + length( ind[s] )  
-      stat <- lik2 - lik1
+      stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
       sel <- which.min(pval) * ( length(s)>0 )
@@ -162,11 +162,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
       vim <- vim + 1
       for ( i in ind[-sela] )  {
         fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-        lik2[i] <- 2 * fit2$loglik
+        lik2[i] <- fit2$loglik
         dof[i] <- length( fit2$be )
       }
       n.tests[vim + 1] <- length( ind[-sela] )
-      stat <- lik2 - lik1
+      stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
       sel <- which.min(pval) * ( length(s)>0 )
@@ -183,11 +183,11 @@ fbed.beta <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) {
       while ( sum(s > 0) > 0 ) {
         for ( i in ind[s] )  {
           fit2 <- beta.reg( y, x[, c(sela, i)], wei = wei )
-          lik2[i] <- 2 * fit2$loglik
+          lik2[i] <- fit2$loglik
           dof[i] <- length( fit2$be )
         }
         n.tests[vim + 1] <- n.tests[vim + 1] + length( ind[s] )
-        stat <- lik2 - lik1
+        stat <- 2 * (lik2 - lik1)
         pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
         s <- which(pval < sig)
         sel <- which.min(pval) * ( length(s)>0 )
