@@ -2,24 +2,19 @@ generatefolds <- function(target, nfolds = 10, stratified = TRUE, seed = FALSE)
   
   a <- paste("Fold", 1:nfolds)
   runs <- sapply(a, function(x) NULL)
-
   if ( seed )  set.seed(1234)
   
   if ( !stratified ) {
     
     options(warn = -1)
     mat <- matrix( sample( length(target) ), ncol = nfolds )
-    
-    for ( i  in 1:c(nfolds - 1) ) {
-       runs[[ i ]] <- mat[, i]
-    }  
-
-      a <- prod( dim(mat) ) - length(target)
-      runs[[ nfolds  ]] <- mat[ 1:c(nrow(mat) - a), nfolds ]
+    for ( i  in 1:c(nfolds - 1) )  runs[[ i ]] <- mat[, i]
+    a <- prod( dim(mat) ) - length(target)
+    runs[[ nfolds  ]] <- mat[ 1:c(nrow(mat) - a), nfolds ]
 
   } else {
     
-   labs <- Rfast::sort_unique(target)
+   labs <- unique(target)
    run <- list()
      
    for ( i in 1:length(labs) ) {
@@ -38,7 +33,6 @@ generatefolds <- function(target, nfolds = 10, stratified = TRUE, seed = FALSE)
   }
 
   runs
-
 }
 
 
