@@ -4,7 +4,7 @@ is.dag <- function(dag) {
     dag[ dag == 2 ] <- 1
   } 
   a <- topological_sort(dag)
-  ( sum(a > 0, na.rm = TRUE) == dim(dag)[2] )
+  any( !is.na(a) ) 
 } 
        
      
