@@ -1,4 +1,4 @@
-min_assoc.ma = function(target, dataset, test, max_k, cvar, statistic, selectedVars, pvalues, stats, univariateModels , selectedVarsOrder, hash, dataInfo, stat_hash, pvalue_hash, robust = robust, ncores = ncores)
+min_assoc.ma = function(target, dataset, test, max_k, cvar, statistic, selectedVars, pvalues, stats, univariateModels , selectedVarsOrder, hash, stat_hash, pvalue_hash)
 {
 
   ma_pvalue = pvalues[[cvar]]; #CHANGE
@@ -24,11 +24,11 @@ min_assoc.ma = function(target, dataset, test, max_k, cvar, statistic, selectedV
     for (i in 1:ncol(subsetcsk) ) {
       s = subsetcsk[,i];
       s = t(t(s));
-      cur_results = test(target = target, dataset = dataset, xIndex = cvar, csIndex = s, statistic = statistic, dataInfo = dataInfo, univariateModels = univariateModels, hash = hash, stat_hash = stat_hash, pvalue_hash = pvalue_hash, robust = robust);
+      cur_results = test(target = target, dataset = dataset, xIndex = cvar, csIndex = s, statistic = statistic, univariateModels = univariateModels, hash = hash, stat_hash = stat_hash, pvalue_hash = pvalue_hash);
       stat_hash = cur_results$stat_hash;
       pvalue_hash = cur_results$pvalue_hash;
       #check if the pvalues and stats should be updated
-      if (cur_results$flag == 1 & !compare_p_values(cur_results$pvalue, ma_pvalue, cur_results$stat, ma_stat) ) {
+      if ( !compare_p_values(cur_results$pvalue, ma_pvalue, cur_results$stat, ma_stat) ) {
         ma_pvalue = cur_results$pvalue;
         pvalues[[cvar]] = cur_results$pvalue;
         ma_stat = cur_results$stat;
@@ -37,6 +37,6 @@ min_assoc.ma = function(target, dataset, test, max_k, cvar, statistic, selectedV
     }
     ck = ck + 1;
   }
-  results <- list(pvalue = ma_pvalue , stat = ma_stat , pvalues = pvalues , stats = stats, stat_hash=stat_hash, pvalue_hash  = pvalue_hash, rob = robust);
+  results <- list(pvalue = ma_pvalue , stat = ma_stat , pvalues = pvalues , stats = stats, stat_hash=stat_hash, pvalue_hash  = pvalue_hash);
   return(results);
 }
\ No newline at end of file
