@@ -1,7 +1,7 @@
-permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NULL, univariateModels = NULL , hash = FALSE, stat_hash = NULL, 
- pvalue_hash = NULL,robust = FALSE, threshold = 0.05, R = 999) {
+permPois = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels = NULL , hash = FALSE, stat_hash = NULL, 
+ pvalue_hash = NULL, threshold = 0.05, R = 999) {
   # TESTINDPOIS Conditional Independence Test for discrete class variables 
-  # PVALUE = TESTINDPOIS(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDPOIS(Y, DATA, XINDEX, CSINDEX,)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # nested models
@@ -11,13 +11,10 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be mixed variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
+  # this method returns: the pvalue PVALUE, the statistic STAT.
   #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1)
   stat = 0;
-  flag = 0;
   csIndex[which(is.na(csIndex))] = 0;
   thres <- threshold * R + 1
   
@@ -29,8 +26,7 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
     if ( !is.null(stat_hash[[key]]) ) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -41,21 +37,19 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
       stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- 1;   #.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   #check input validity
   if(xIndex < 0 || csIndex < 0) {
     message(paste("error in testIndPois : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs)!=0 )   {
     if ( is.null(dim(cs)[2]) ) {    #cs is a vector
@@ -64,7 +58,7 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
           stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
@@ -74,7 +68,7 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -95,8 +89,8 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
         step <- step + ( bit2$deviance < dev2 )
         j <- j + 1
       }
-      pvalue <- (step + 1) / (R + 1) 
-	} else  pvalue <- 1  
+      pvalue <- log( (step + 1) / (R + 1) )
+	} else  pvalue <- log(1) 
   } else {
     fit1 = glm(target ~ cs, poisson, weights = wei, model = FALSE)
     fit2 = glm(target ~ cs + xb, poisson, weights = wei, model = FALSE)
@@ -112,15 +106,12 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
         step <- step + ( bit2$deviance < dev2 )
         j <- j + 1
       }
-      pvalue <- (step + 1) / (R + 1) 
-	} else  pvalue <- 1   
+      pvalue <- log( (step + 1) / (R + 1) ) 
+	} else  pvalue <- log(1)  
   } 
-  flag = 1;
-  #last error check
   if ( is.na(pvalue) || is.na(stat) )   {
-    pvalue = 1;
+    pvalue = log(1)
     stat = 0;
-    flag = 0;
   } else {
     #update hash objects
     if ( hash )  {
@@ -129,7 +120,7 @@ permPois = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NUL
     }
   }
   #testerrorcaseintrycatch(4);
-  results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
   
 }
\ No newline at end of file
